retools
=======

.. autofunction:: txttk.retools.condense
.. autofunction:: txttk.retools.is_solid
.. autofunction:: txttk.retools.is_packed
.. autofunction:: txttk.retools.consolidate
.. autofunction:: txttk.retools.danger_unpack
.. autofunction:: txttk.retools.unpack
.. autofunction:: txttk.retools.parallel
.. autofunction:: txttk.retools.concat
.. autofunction:: txttk.retools.nocatch
.. autofunction:: txttk.retools.nocatchall
.. autofunction:: txttk.retools.option
